"""
Xero Connections API
"""

from .api_base import ApiBase


class Connections(ApiBase):
    """
    Class for Connections
    """
    GET_CONNECTIONS = '/connections'
    REVOKE_CONNECTION = '/connections/{}'

    def get_all(self):
        """
        Get all Connections

        Returns:
            List of all Connections
        """

        return self._get_request(Connections.GET_CONNECTIONS)


    def remove_connection(self, connection_id: str):
        """
        Remove tenant connection

        Parameters:
            connection_id (str): Connection ID
        """

        return self._delete_request(Connections.REVOKE_CONNECTION.format(connection_id))



"""
Xero Linked Transactions API
"""

from .api_base import ApiBase


class LinkedTransactions(ApiBase):
    """
    Class for Linked Transactions API
    """

    POST_LINKED_TRANSACTION = '/api.xro/2.0/LinkedTransactions'

    def post(self, data):
        """
        Create new invoice

        Parameters:
            data (dict): Data to create invoice

        Returns:
             Response from API
        """

        return self._post_request(data, LinkedTransactions.POST_LINKED_TRANSACTION)



"""
Xero Tax Rates API
"""

from .api_base import ApiBase


class TaxRates(ApiBase):
    """
    Class for Tax Rates API
    """

    GET_TAX_RATES = '/api.xro/2.0/TaxRates'
    POST_TAX_RATES = '/api.xro/2.0/TaxRates'
    PUT_TAX_RATES = '/api.xro/2.0/TaxRates'

    def get_all(self):
        """
        Get all Tax Rates

        Returns:
            List of all Tax Rates
        """

        return self._get_request(TaxRates.GET_TAX_RATES)

    def post(self, data):
        """
        Create new Bank Transaction

        Parameters:
            data (dict): Data to create tax rates

        Returns:
             Response from API
        """

        return self._post_request(data, TaxRates.POST_TAX_RATES)

    def put(self, data: dict):
        """
        Create or replace tax rate

        Parameters:
            data (dict): Data to Create or replace tax rate

        Returns:
                Response from API
        """

        return self._update_request(data, TaxRates.PUT_TAX_RATES)



"""
Xero Accounts API
"""

from .api_base import ApiBase


class Accounts(ApiBase):
    """
    Class for Accounts API
    """

    GET_ACCOUNTS = '/api.xro/2.0/Accounts'

    def get_all(self, modified_after: str = None):
        """
        Get all accounts

        :param modified_after: Optional modified_after parameter as a string in 2009-11-12T00:00:00 format

        Returns:
            List of all accounts
        """

        return self._get_request(Accounts.GET_ACCOUNTS, additional_headers={'If-Modified-Since': modified_after})



"""
Xero Currencies API
"""

from .api_base import ApiBase


class Currencies(ApiBase):
    """
    Class for Currencies API
    """

    CURRENCIES = '/api.xro/2.0/Currencies'

    def get_all(self):
        """
        Get all Currencies

        Returns:
            List of all Currencies
        """

        return self._get_request(Currencies.CURRENCIES)


    def post(self, data: dict):
        """
        Create new currency

        Parameters:
            data (dict): Data to create currency

        Returns:
             Response from API
        """

        return self._update_request(data, Currencies.CURRENCIES)
